==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount.md <==
# AwsOrganizationsManagementAccount


```text
aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')
```



| Illustration | AwsOrganizationsManagementAccount | AwsOrganizationsManagementAccountCard | AwsOrganizationsManagementAccountGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount.png) | ![illustration for AwsOrganizationsManagementAccount](../../../aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount.Local.png) | ![illustration for AwsOrganizationsManagementAccountCard](../../../aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccountCard.Local.png) | ![illustration for AwsOrganizationsManagementAccountGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccountGroup.Local.png) |




## AwsOrganizationsManagementAccount

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccount
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccount('AwsOrganizationsManagementAccount', 'Aws Organizations Management Account', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccount
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccount('AwsOrganizationsManagementAccount', 'Aws Organizations Management Account', 'an optional tech label')
@enduml
```

## AwsOrganizationsManagementAccountCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccountCard
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccountCard('AwsOrganizationsManagementAccountCard', 'Aws Organizations Management Account Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccountCard
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccountCard('AwsOrganizationsManagementAccountCard', 'Aws Organizations Management Account Card', 'an optional description')
@enduml
```

## AwsOrganizationsManagementAccountGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccountGroup
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccountGroup('AwsOrganizationsManagementAccountGroup', 'Aws Organizations Management Account Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccountGroup
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccountGroup('AwsOrganizationsManagementAccountGroup', 'Aws Organizations Management Account Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount.md <==
# AwsOrganizationsManagementAccount


```text
aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')
```



| Illustration | AwsOrganizationsManagementAccount | AwsOrganizationsManagementAccountCard | AwsOrganizationsManagementAccountGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount.png) | ![illustration for AwsOrganizationsManagementAccount](../../../aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount.Local.png) | ![illustration for AwsOrganizationsManagementAccountCard](../../../aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccountCard.Local.png) | ![illustration for AwsOrganizationsManagementAccountGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccountGroup.Local.png) |




## AwsOrganizationsManagementAccount

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccount
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccount('AwsOrganizationsManagementAccount', 'Aws Organizations Management Account', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccount
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccount('AwsOrganizationsManagementAccount', 'Aws Organizations Management Account', 'an optional tech label')
@enduml
```

## AwsOrganizationsManagementAccountCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccountCard
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccountCard('AwsOrganizationsManagementAccountCard', 'Aws Organizations Management Account Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccountCard
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccountCard('AwsOrganizationsManagementAccountCard', 'Aws Organizations Management Account Card', 'an optional description')
@enduml
```

## AwsOrganizationsManagementAccountGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccountGroup
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccountGroup('AwsOrganizationsManagementAccountGroup', 'Aws Organizations Management Account Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOrganizationsManagementAccountGroup
include('aws-20210730/Resource/ManagementGovernance/AwsOrganizationsManagementAccount')

' renders the element
AwsOrganizationsManagementAccountGroup('AwsOrganizationsManagementAccountGroup', 'Aws Organizations Management Account Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
